@@ -9,7 +9,7 @@ from r3sponse import r3sponse
 # functions.
 def __get_operating_system__():
 	os = platform.system().lower()
-	if os in ["darwin"]: return "osx"
+	if os in ["darwin"]: return "macos"
 	elif os in ["linux"]: return "linux"
 	else: raise ValueError(f"Unsupported operating system: [{os}].")
 
@@ -24,7 +24,7 @@ GROUP = "root"
 HOME_BASE = "/home/"
 HOME = f"/home/{os.environ.get('USER')}/"
 MEDIA = f"/media/{os.environ.get('USER')}/"
-if OS in ["osx"]: 
+if OS in ["macos"]: 
 	HOME_BASE = "/Users/"
 	HOME = f"/Users/{os.environ.get('USER')}/"
 	MEDIA = f"/Volumes/"
